function _typeof(o) {
  "@babel/helpers - typeof";

  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) {
    return typeof o;
  } : function (o) {
    return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o;
  }, _typeof(o);
}

function toPrimitive(t, r) {
  if ("object" != _typeof(t) || !t) return t;
  var e = t[Symbol.toPrimitive];
  if (void 0 !== e) {
    var i = e.call(t, r || "default");
    if ("object" != _typeof(i)) return i;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return ("string" === r ? String : Number)(t);
}

function toPropertyKey(t) {
  var i = toPrimitive(t, "string");
  return "symbol" == _typeof(i) ? i : String(i);
}

function _defineProperty(obj, key, value) {
  key = toPropertyKey(key);
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}

/**
 * Adapted from React: https://github.com/facebook/react/blob/master/packages/shared/formatProdErrorMessage.js
 *
 * Do not require this module directly! Use normal throw error calls. These messages will be replaced with error codes
 * during build.
 * @param {number} code
 */
function formatProdErrorMessage(code) {
  return "Minified Redux error #" + code + "; visit https://redux.js.org/Errors?code=" + code + " for the full message or " + 'use the non-minified dev environment for full errors. ';
}

/**
 * These are private action types reserved by Redux.
 * For any unknown actions, you must return the current state.
 * If the current state is undefined, you must return the initial state.
 * Do not reference these action types directly in your code.
 */
var randomString = function randomString() {
  return Math.random().toString(36).substring(7).split('').join('.');
};
var ActionTypes = {
  INIT: "@@redux/INIT" + randomString(),
  REPLACE: "@@redux/REPLACE" + randomString(),
  PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
    return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
  }
};

/**
 * @param {any} obj The object to inspect.
 * @returns {boolean} True if the argument appears to be a plain object.
 */
function isPlainObject(obj) {
  if (_typeof(obj) !== 'object' || obj === null) return false;
  var proto = obj;
  while (Object.getPrototypeOf(proto) !== null) {
    proto = Object.getPrototypeOf(proto);
  }
  return Object.getPrototypeOf(obj) === proto;
}

// Inlined / shortened version of `kindOf` from https://github.com/jonschlinkert/kind-of
function miniKindOf(val) {
  if (val === void 0) return 'undefined';
  if (val === null) return 'null';
  var type = _typeof(val);
  switch (type) {
    case 'boolean':
    case 'string':
    case 'number':
    case 'symbol':
    case 'function':
      {
        return type;
      }
  }
  if (Array.isArray(val)) return 'array';
  if (isDate(val)) return 'date';
  if (isError(val)) return 'error';
  var constructorName = ctorName(val);
  switch (constructorName) {
    case 'Symbol':
    case 'Promise':
    case 'WeakMap':
    case 'WeakSet':
    case 'Map':
    case 'Set':
      return constructorName;
  } // other

  return type.slice(8, -1).toLowerCase().replace(/\s/g, '');
}
function ctorName(val) {
  return typeof val.constructor === 'function' ? val.constructor.name : null;
}
function isError(val) {
  return val instanceof Error || typeof val.message === 'string' && val.constructor && typeof val.constructor.stackTraceLimit === 'number';
}
function isDate(val) {
  if (val instanceof Date) return true;
  return typeof val.toDateString === 'function' && typeof val.getDate === 'function' && typeof val.setDate === 'function';
}
function kindOf(val) {
  var typeOfVal = _typeof(val);
  if (process.env.NODE_ENV !== 'production') {
    typeOfVal = miniKindOf(val);
  }
  return typeOfVal;
}

/**
 * Prints a warning in the console if it exists.
 *
 * @param {String} message The warning message.
 * @returns {void}
 */
function warning(message) {
  /* eslint-disable no-console */
  if (typeof console !== 'undefined' && typeof console.error === 'function') {
    console.error(message);
  }
  /* eslint-enable no-console */

  try {
    // This error was thrown as a convenience so that if you enable
    // "break on all exceptions" in your console,
    // it would pause the execution at this line.
    throw new Error(message);
  } catch (e) {} // eslint-disable-line no-empty
}
function getUnexpectedStateShapeWarningMessage(inputState, reducers, action, unexpectedKeyCache) {
  var reducerKeys = Object.keys(reducers);
  var argumentName = action && action.type === ActionTypes.INIT ? 'preloadedState argument passed to createStore' : 'previous state received by the reducer';
  if (reducerKeys.length === 0) {
    return 'Store does not have a valid reducer. Make sure the argument passed ' + 'to combineReducers is an object whose values are reducers.';
  }
  if (!isPlainObject(inputState)) {
    return "The " + argumentName + " has unexpected type of \"" + kindOf(inputState) + "\". Expected argument to be an object with the following " + ("keys: \"" + reducerKeys.join('", "') + "\"");
  }
  var unexpectedKeys = Object.keys(inputState).filter(function (key) {
    return !reducers.hasOwnProperty(key) && !unexpectedKeyCache[key];
  });
  unexpectedKeys.forEach(function (key) {
    unexpectedKeyCache[key] = true;
  });
  if (action && action.type === ActionTypes.REPLACE) return;
  if (unexpectedKeys.length > 0) {
    return "Unexpected " + (unexpectedKeys.length > 1 ? 'keys' : 'key') + " " + ("\"" + unexpectedKeys.join('", "') + "\" found in " + argumentName + ". ") + "Expected to find one of the known reducer keys instead: " + ("\"" + reducerKeys.join('", "') + "\". Unexpected keys will be ignored.");
  }
}
function assertReducerShape(reducers) {
  Object.keys(reducers).forEach(function (key) {
    var reducer = reducers[key];
    var initialState = reducer(undefined, {
      type: ActionTypes.INIT
    });
    if (typeof initialState === 'undefined') {
      throw new Error(process.env.NODE_ENV === "production" ? formatProdErrorMessage(12) : "The slice reducer for key \"" + key + "\" returned undefined during initialization. " + "If the state passed to the reducer is undefined, you must " + "explicitly return the initial state. The initial state may " + "not be undefined. If you don't want to set a value for this reducer, " + "you can use null instead of undefined.");
    }
    if (typeof reducer(undefined, {
      type: ActionTypes.PROBE_UNKNOWN_ACTION()
    }) === 'undefined') {
      throw new Error(process.env.NODE_ENV === "production" ? formatProdErrorMessage(13) : "The slice reducer for key \"" + key + "\" returned undefined when probed with a random type. " + ("Don't try to handle '" + ActionTypes.INIT + "' or other actions in \"redux/*\" ") + "namespace. They are considered private. Instead, you must return the " + "current state for any unknown actions, unless it is undefined, " + "in which case you must return the initial state, regardless of the " + "action type. The initial state may not be undefined, but can be null.");
    }
  });
}
/**
 * Turns an object whose values are different reducer functions, into a single
 * reducer function. It will call every child reducer, and gather their results
 * into a single state object, whose keys correspond to the keys of the passed
 * reducer functions.
 *
 * @param {Object} reducers An object whose values correspond to different
 * reducer functions that need to be combined into one. One handy way to obtain
 * it is to use ES6 `import * as reducers` syntax. The reducers may never return
 * undefined for any action. Instead, they should return their initial state
 * if the state passed to them was undefined, and the current state for any
 * unrecognized action.
 *
 * @returns {Function} A reducer function that invokes every reducer inside the
 * passed object, and builds a state object with the same shape.
 */

function combineReducers(reducers) {
  var reducerKeys = Object.keys(reducers);
  var finalReducers = {};
  for (var i = 0; i < reducerKeys.length; i++) {
    var key = reducerKeys[i];
    if (process.env.NODE_ENV !== 'production') {
      if (typeof reducers[key] === 'undefined') {
        warning("No reducer provided for key \"" + key + "\"");
      }
    }
    if (typeof reducers[key] === 'function') {
      finalReducers[key] = reducers[key];
    }
  }
  var finalReducerKeys = Object.keys(finalReducers); // This is used to make sure we don't warn about the same
  // keys multiple times.

  var unexpectedKeyCache;
  if (process.env.NODE_ENV !== 'production') {
    unexpectedKeyCache = {};
  }
  var shapeAssertionError;
  try {
    assertReducerShape(finalReducers);
  } catch (e) {
    shapeAssertionError = e;
  }
  return function combination(state, action) {
    if (state === void 0) {
      state = {};
    }
    if (shapeAssertionError) {
      throw shapeAssertionError;
    }
    if (process.env.NODE_ENV !== 'production') {
      var warningMessage = getUnexpectedStateShapeWarningMessage(state, finalReducers, action, unexpectedKeyCache);
      if (warningMessage) {
        warning(warningMessage);
      }
    }
    var hasChanged = false;
    var nextState = {};
    for (var _i = 0; _i < finalReducerKeys.length; _i++) {
      var _key = finalReducerKeys[_i];
      var reducer = finalReducers[_key];
      var previousStateForKey = state[_key];
      var nextStateForKey = reducer(previousStateForKey, action);
      if (typeof nextStateForKey === 'undefined') {
        var actionType = action && action.type;
        throw new Error(process.env.NODE_ENV === "production" ? formatProdErrorMessage(14) : "When called with an action of type " + (actionType ? "\"" + String(actionType) + "\"" : '(unknown type)') + ", the slice reducer for key \"" + _key + "\" returned undefined. " + "To ignore an action, you must explicitly return the previous state. " + "If you want this reducer to hold no value, you can return null instead of undefined.");
      }
      nextState[_key] = nextStateForKey;
      hasChanged = hasChanged || nextStateForKey !== previousStateForKey;
    }
    hasChanged = hasChanged || finalReducerKeys.length !== Object.keys(state).length;
    return hasChanged ? nextState : state;
  };
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;
  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
  return arr2;
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

var ADD_COMPONENT = 'ADD_COMPONENT';
var REMOVE_COMPONENT = 'REMOVE_COMPONENT';
var WATCH_COMPONENT = 'WATCH_COMPONENT';
var SET_QUERY = 'SET_QUERY';
var SET_APPBASE_QUERY = 'SET_APPBASE_QUERY';
var SET_QUERY_OPTIONS = 'SET_QUERY_OPTIONS';
var UPDATE_HITS = 'UPDATE_HITS';
var UPDATE_AGGS = 'UPDATE_AGGS';
var UPDATE_COMPOSITE_AGGS = 'UPDATE_COMPOSITE_AGGS';
var ADD_CONFIG = 'ADD_CONFIG';
var UPDATE_CONFIG = 'UPDATE_CONFIG';
var ADD_APPBASE_REF = 'ADD_APPBASE_REF';
var ADD_ANALYTICS_REF = 'ADD_ANALYTICS_REF';
var LOG_QUERY = 'LOG_QUERY';
var LOG_COMBINED_QUERY = 'LOG_COMBINED_QUERY';
var SET_INTERNAL_VALUE = 'SET_INTERNAL_VALUE';
var PATCH_VALUE = 'PATCH_VALUE';
var CLEAR_VALUES = 'CLEAR_VALUES';
var SET_LOADING = 'SET_LOADING';
var SET_ERROR = 'SET_ERROR';
var SET_TIMESTAMP = 'SET_TIMESTAMP';
var SET_HEADERS = 'SET_HEADERS';
var SET_MAP_DATA = 'SET_MAP_DATA';
var SET_MAP_RESULTS = 'SET_MAP_RESULTS';
var SET_QUERY_LISTENER = 'SET_QUERY_LISTENER';
var SET_SEARCH_ID = 'SET_SEARCH_ID';
var SET_PROMOTED_RESULTS = 'SET_PROMOTED_RESULTS';
var SET_DEFAULT_QUERY = 'SET_DEFAULT_QUERY';
var SET_CUSTOM_QUERY = 'SET_CUSTOM_QUERY';
var SET_CUSTOM_HIGHLIGHT_OPTIONS = 'SET_CUSTOM_HIGHLIGHT_OPTIONS';
var SET_CUSTOM_DATA = 'SET_CUSTOM_DATA';
var SET_APPLIED_SETTINGS = 'SET_APPLIED_SETTINGS';
var SET_PROPS = 'SET_PROPS';
var UPDATE_PROPS = 'UPDATE_PROPS';
var REMOVE_PROPS = 'REMOVE_PROPS';
var SET_SUGGESTIONS_SEARCH_VALUE = 'SET_SUGGESTIONS_SEARCH_VALUE';
var CLEAR_SUGGESTIONS_SEARCH_VALUE = 'CLEAR_SUGGESTIONS_SEARCH_VALUE';
var SET_SUGGESTIONS_SEARCH_ID = 'SET_SUGGESTIONS_SEARCH_ID';
var UPDATE_ANALYTICS_CONFIG = 'UPDATE_ANALYTICS_CONFIG';
var SET_RAW_DATA = 'SET_RAW_DATA';
var SET_POPULAR_SUGGESTIONS = 'SET_POPULAR_SUGGESTIONS';
var SET_DEFAULT_POPULAR_SUGGESTIONS = 'SET_DEFAULT_POPULAR_SUGGESTIONS';
var SET_QUERY_TO_HITS = 'SET_QUERY_TO_HITS';
var RECENT_SEARCHES_SUCCESS = 'RECENT_SEARCHES_SUCCESS';
var RECENT_SEARCHES_ERROR = 'RECENT_SEARCHES_ERROR';
var SET_VALUE = 'SET_VALUE';
var SET_VALUES = 'SET_VALUES';
var RESET_TO_DEFAULT = 'RESET_TO_DEFAULT';
var SET_GOOGLE_MAP_SCRIPT_LOADING = 'SET_GOOGLE_MAP_SCRIPT_LOADING';
var SET_GOOGLE_MAP_SCRIPT_LOADED = 'SET_GOOGLE_MAP_SCRIPT_LOADED';
var SET_GOOGLE_MAP_SCRIPT_ERROR = 'SET_GOOGLE_MAP_SCRIPT_ERROR';
var SET_REGISTERED_COMPONENT_TIMESTAMP = 'SET_REGISTERED_COMPONENT_TIMESTAMP';
var REMOVE_REGISTERED_COMPONENT_TIMESTAMP = 'REMOVE_REGISTERED_COMPONENT_TIMESTAMP';
var SET_AI_RESPONSE = 'SET_AI_RESPONSE';
var REMOVE_AI_RESPONSE = 'REMOVE_AI_RESPONSE';
var SET_AI_RESPONSE_ERROR = 'SET_AI_RESPONSE_ERROR';
var SET_AI_RESPONSE_LOADING = 'SET_AI_RESPONSE_LOADING';

function componentsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === ADD_COMPONENT) {
    return [].concat(_toConsumableArray(state), [action.component]);
  } else if (action.type === REMOVE_COMPONENT) {
    return state.filter(function (element) {
      return element !== action.component;
    });
  }
  return state;
}

function ownKeys$w(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$w(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$w(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$w(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function getWatchList(depTree) {
  var list = Object.values(depTree);
  var components = [];
  list.forEach(function (item) {
    if (typeof item === 'string') {
      components.push(item);
    } else if (Array.isArray(item)) {
      item.forEach(function (component) {
        if (typeof component === 'string') {
          components.push(component);
        } else {
          // in this case, we have { <conjunction>: <> } object inside the array
          components.push.apply(components, _toConsumableArray(getWatchList(component)));
        }
      });
    } else if (_typeof(item) === 'object' && item !== null) {
      components.push.apply(components, _toConsumableArray(getWatchList(item)));
    }
  });
  return components.filter(function (value, index, array) {
    return array.indexOf(value) === index;
  });
}
function watchManReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === WATCH_COMPONENT) {
    var watchList = getWatchList(action.react);
    var newState = _objectSpread$w({}, state);
    Object.keys(newState).forEach(function (key) {
      newState[key] = newState[key].filter(function (value) {
        return value !== action.component;
      });
    });
    watchList.forEach(function (item) {
      if (Array.isArray(newState[item])) {
        newState[item] = [].concat(_toConsumableArray(newState[item]), [action.component]);
      } else {
        newState[item] = [action.component];
      }
    });
    return newState;
  }
  return state;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};
  var target = _objectWithoutPropertiesLoose(source, excluded);
  var key, i;
  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }
  return target;
}

function _toPropertyKey$n(t) { var i = _toPrimitive$n(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$n(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$v(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$v(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$v(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$v(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function dependencyTreeReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === WATCH_COMPONENT) {
    return _objectSpread$v(_objectSpread$v({}, state), {}, _defineProperty({}, action.component, action.react));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$n));
    return obj;
  }
  return state;
}

function _toPropertyKey$m(t) { var i = _toPrimitive$m(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$m(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$u(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$u(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$u(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$u(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function queryReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_QUERY) {
    return _objectSpread$u(_objectSpread$u({}, state), {}, _defineProperty({}, action.component, action.query));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$m));
    return obj;
  }
  return state;
}

function ownKeys$t(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$t(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$t(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$t(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function appbaseQueryReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_APPBASE_QUERY) {
    return _objectSpread$t(_objectSpread$t({}, state), action.query);
  }
  return state;
}

function _toPropertyKey$l(t) { var i = _toPrimitive$l(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$l(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$s(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$s(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$s(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$s(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function queryOptionsReducer$1() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_QUERY_OPTIONS) {
    return _objectSpread$s(_objectSpread$s({}, state), {}, _defineProperty({}, action.component, action.options));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$l));
    return obj;
  }
  return state;
}

var componentTypes = {
  reactiveList: 'REACTIVELIST',
  // search components
  dataSearch: 'DATASEARCH',
  categorySearch: 'CATEGORYSEARCH',
  searchBox: 'SEARCHBOX',
  // list components
  singleList: 'SINGLELIST',
  multiList: 'MULTILIST',
  singleDataList: 'SINGLEDATALIST',
  tabDataList: 'TABDATALIST',
  singleDropdownList: 'SINGLEDROPDOWNLIST',
  multiDataList: 'MULTIDATALIST',
  multiDropdownList: 'MULTIDROPDOWNLIST',
  singleDropdownRange: 'SINGLEDROPDOWNRANGE',
  treeList: 'TREELIST',
  // basic components
  numberBox: 'NUMBERBOX',
  tagCloud: 'TAGCLOUD',
  toggleButton: 'TOGGLEBUTTON',
  reactiveComponent: 'REACTIVECOMPONENT',
  // range components
  datePicker: 'DATEPICKER',
  dateRange: 'DATERANGE',
  dynamicRangeSlider: 'DYNAMICRANGESLIDER',
  multiDropdownRange: 'MULTIDROPDOWNRANGE',
  singleRange: 'SINGLERANGE',
  multiRange: 'MULTIRANGE',
  rangeSlider: 'RANGESLIDER',
  ratingsFilter: 'RATINGSFILTER',
  rangeInput: 'RANGEINPUT',
  // map components
  geoDistanceDropdown: 'GEO_DISTANCE_DROPDOWN',
  geoDistanceSlider: 'GEO_DISTANCE_SLIDER',
  reactiveMap: 'REACTIVE_MAP',
  // chart components
  reactiveChart: 'REACTIVE_CHART',
  // ai component
  AIAnswer: 'AI_ANSWER'
};
var AI_LOCAL_CACHE_KEY = 'AISessions';

// defaultAnalytics Config
var defaultAnalyticsConfig = {
  emptyQuery: true,
  suggestionAnalytics: true,
  userId: null,
  customEvents: null,
  enableQueryRules: true
};

function ownKeys$r(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$r(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$r(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$r(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function configReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
    analyticsConfig: defaultAnalyticsConfig,
    lock: false
  };
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === ADD_CONFIG) {
    return _objectSpread$r(_objectSpread$r({}, state), {}, {
      analyticsConfig: _objectSpread$r(_objectSpread$r({}, defaultAnalyticsConfig), action.analyticsConfig)
    });
  } else if (action.type === UPDATE_ANALYTICS_CONFIG) {
    return _objectSpread$r(_objectSpread$r({}, state), {}, {
      analyticsConfig: _objectSpread$r(_objectSpread$r({}, state.analyticsConfig), action.analyticsConfig)
    });
  } else if (action.type === UPDATE_CONFIG) {
    return _objectSpread$r(_objectSpread$r({}, state), action.config);
  }
  return state;
}

function appbaseRefReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === ADD_APPBASE_REF) {
    return action.appbaseRef;
  }
  return state;
}

function _toPropertyKey$k(t) { var i = _toPrimitive$k(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$k(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$q(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$q(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$q(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$q(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function hitsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === UPDATE_HITS) {
    if (action.append) {
      return _objectSpread$q(_objectSpread$q({}, state), {}, _defineProperty({}, action.component, {
        hits: [].concat(_toConsumableArray(state[action.component].hits), _toConsumableArray(action.hits)),
        total: action.total,
        time: action.time,
        hidden: action.hidden || 0
      }));
    }
    return _objectSpread$q(_objectSpread$q({}, state), {}, _defineProperty({}, action.component, {
      hits: action.hits,
      total: action.total,
      time: action.time,
      hidden: action.hidden || 0
    }));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$k));
    return obj;
  }
  return state;
}

function _toPropertyKey$j(t) { var i = _toPrimitive$j(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$j(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$p(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$p(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$p(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$p(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function logsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === LOG_QUERY) {
    return _objectSpread$p(_objectSpread$p({}, state), {}, _defineProperty({}, action.component, action.query));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$j));
    return obj;
  }
  return state;
}

function _toPropertyKey$i(t) { var i = _toPrimitive$i(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$i(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$o(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$o(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$o(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$o(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function combinedLogsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === LOG_COMBINED_QUERY) {
    return _objectSpread$o(_objectSpread$o({}, state), {}, _defineProperty({}, action.component, action.query));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$i));
    return obj;
  }
  return state;
}

var _excluded$2 = ["value"];
function _toPropertyKey$h(t) { var i = _toPrimitive$h(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$h(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$n(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$n(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$n(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$n(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function valueReducer$1() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  switch (action.type) {
    case SET_VALUE:
      {
        var newState = {};
        Object.keys(action.componentsToReset || {}).forEach(function (id) {
          newState[id] = _objectSpread$n(_objectSpread$n({}, state[id]), {}, {
            value: action.componentsToReset[id]
          });
        });
        return _objectSpread$n(_objectSpread$n(_objectSpread$n({}, state), newState), {}, _defineProperty({}, action.component, {
          value: action.value,
          label: action.label || action.component,
          showFilter: action.showFilter,
          URLParams: action.URLParams,
          componentType: action.componentType,
          category: action.category,
          meta: action.meta,
          reference: action.reference
        }));
      }
    case SET_VALUES:
      {
        var componentKeys = action.componentsValues ? Object.keys(action.componentsValues) : [];
        if (componentKeys.length) {
          var _newState = {};
          componentKeys.forEach(function (component) {
            var _action$componentsVal = action.componentsValues[component],
              value = _action$componentsVal.value,
              rest = _objectWithoutProperties(_action$componentsVal, _excluded$2);
            _newState[component] = _objectSpread$n(_objectSpread$n({}, state[component]), {}, {
              value: value
            }, rest);
          });
          return _objectSpread$n(_objectSpread$n({}, state), _newState);
        }
        return state;
      }
    case PATCH_VALUE:
      return _objectSpread$n(_objectSpread$n({}, state), {}, _defineProperty({}, action.component, _objectSpread$n(_objectSpread$n({}, state[action.component]), action.payload)));
    case CLEAR_VALUES:
      {
        var nextState = {};
        if (action.resetValues) {
          Object.keys(action.resetValues).forEach(function (componentId) {
            nextState[componentId] = _objectSpread$n(_objectSpread$n({}, state[componentId]), {}, {
              value: action.resetValues[componentId]
            });
          });
        }
        // clearAllBlacklistComponents has more priority over reset values
        if (Array.isArray(action.clearAllBlacklistComponents)) {
          Object.keys(state).forEach(function (componentId) {
            if (action.clearAllBlacklistComponents.includes(componentId)) {
              nextState[componentId] = state[componentId];
            }
          });
        }
        return nextState;
      }
    case REMOVE_COMPONENT:
      {
        var _action$component = action.component;
          state[_action$component];
          var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$h));
        return obj;
      }
    case RESET_TO_DEFAULT:
      return _objectSpread$n(_objectSpread$n({}, state), action.defaultValues);
    default:
      return state;
  }
}

function _toPropertyKey$g(t) { var i = _toPrimitive$g(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$g(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$m(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$m(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$m(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$m(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function valueReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  switch (action.type) {
    case SET_INTERNAL_VALUE:
      return _objectSpread$m(_objectSpread$m({}, state), {}, _defineProperty({}, action.component, {
        value: action.value,
        componentType: action.componentType,
        category: action.category,
        meta: action.meta
      }));
    case CLEAR_VALUES:
      {
        var nextState = {};
        if (action.resetValues) {
          Object.keys(action.resetValues).forEach(function (componentId) {
            nextState[componentId] = _objectSpread$m(_objectSpread$m({}, state[componentId]), {}, {
              value: action.resetValues[componentId]
            });
          });
        }
        // clearAllBlacklistComponents has more priority over reset values
        if (Array.isArray(action.clearAllBlacklistComponents)) {
          Object.keys(state).forEach(function (componentId) {
            if (action.clearAllBlacklistComponents.includes(componentId)) {
              nextState[componentId] = state[componentId];
            }
          });
        }
        return nextState;
      }
    case RESET_TO_DEFAULT:
      return _objectSpread$m(_objectSpread$m({}, state), action.defaultValues);
    case REMOVE_COMPONENT:
      {
        var _action$component = action.component;
          state[_action$component];
          var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$g));
        return obj;
      }
    default:
      return state;
  }
}

function _toPropertyKey$f(t) { var i = _toPrimitive$f(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$f(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$l(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$l(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$l(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$l(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function loadingReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_LOADING) {
    var requestCount = state["".concat(action.component, "_active")] || 0;
    if (action.isLoading) {
      requestCount += 1;
    } else if (requestCount) {
      requestCount -= 1;
    }
    return _objectSpread$l(_objectSpread$l({}, state), {}, _defineProperty(_defineProperty({}, action.component, action.isLoading), "".concat(action.component, "_active"), requestCount), action.isLoading ? _defineProperty({}, "".concat(action.component, "_timestamp"), new Date().getTime()) : null);
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component,
      _ref2 = "".concat(action.component, "_active");
      state[_action$component];
      state[_ref2];
      var obj = _objectWithoutProperties(state, [_action$component, _ref2].map(_toPropertyKey$f));
    return obj;
  }
  return state;
}

function _toPropertyKey$e(t) { var i = _toPrimitive$e(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$e(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$k(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$k(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$k(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$k(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function errorReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_ERROR) {
    return _objectSpread$k(_objectSpread$k({}, state), {}, _defineProperty({}, action.component, action.error));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$e));
    return obj;
  }
  return state;
}

function _toPropertyKey$d(t) { var i = _toPrimitive$d(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$d(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$j(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$j(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$j(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$j(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function timestampReducer$1() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_TIMESTAMP) {
    return _objectSpread$j(_objectSpread$j({}, state), {}, _defineProperty({}, action.component, action.timestamp));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$d));
    return obj;
  }
  return state;
}

function headersReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_HEADERS) {
    return action.headers;
  }
  return state;
}

function _toPropertyKey$c(t) { var i = _toPrimitive$c(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$c(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$i(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$i(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$i(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$i(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function mapDataReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_MAP_DATA) {
    return _objectSpread$i(_objectSpread$i({}, state), {}, _defineProperty({}, action.componentId, {
      query: action.query,
      persistMapQuery: action.persistMapQuery
    }));
  } else if (action.type === SET_MAP_RESULTS) {
    return _objectSpread$i(_objectSpread$i({}, state), {}, _defineProperty({}, action.componentId, _objectSpread$i(_objectSpread$i({}, state[action.componentId]), action.payload)));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$c));
    return obj;
  }
  return state;
}

function _toPropertyKey$b(t) { var i = _toPrimitive$b(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$b(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$h(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$h(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$h(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$h(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function queryListenerReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_QUERY_LISTENER) {
    return _objectSpread$h(_objectSpread$h({}, state), {}, _defineProperty({}, action.component, {
      onQueryChange: action.onQueryChange,
      onError: action.onError
    }));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$b));
    return obj;
  }
  return state;
}

function ownKeys$g(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$g(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$g(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$g(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var initialState = {
  searchValue: null,
  searchId: null,
  // Maintain the suggestions analytics separately
  suggestionsSearchId: null,
  suggestionsSearchValue: null
};
var searchComponents = [componentTypes.dataSearch, componentTypes.categorySearch];
function analyticsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments.length > 1 ? arguments[1] : undefined;
  switch (action.type) {
    case SET_VALUE:
      if (searchComponents.includes(action.componentType)) {
        return {
          searchValue: action.value,
          searchId: null
        };
      }
      return state;
    case SET_SEARCH_ID:
      return _objectSpread$g(_objectSpread$g({}, state), {}, {
        searchId: action.searchId
      });
    case SET_SUGGESTIONS_SEARCH_VALUE:
      return _objectSpread$g(_objectSpread$g({}, state), {}, {
        suggestionsSearchValue: action.value,
        suggestionsSearchId: null
      });
    case SET_SUGGESTIONS_SEARCH_ID:
      return _objectSpread$g(_objectSpread$g({}, state), {}, {
        suggestionsSearchId: action.searchId
      });
    case CLEAR_SUGGESTIONS_SEARCH_VALUE:
      return _objectSpread$g(_objectSpread$g({}, state), {}, {
        suggestionsSearchValue: null,
        suggestionsSearchId: null
      });
    default:
      return state;
  }
}

function _toPropertyKey$a(t) { var i = _toPrimitive$a(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$a(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$f(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$f(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$f(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$f(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function promotedResultsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_PROMOTED_RESULTS) {
    return _objectSpread$f(_objectSpread$f({}, state), {}, _defineProperty({}, action.component, action.results.map(function (item) {
      return _objectSpread$f(_objectSpread$f({}, item), {}, {
        _promoted: true
      });
    })));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$a));
    return obj;
  }
  return state;
}

function _toPropertyKey$9(t) { var i = _toPrimitive$9(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$9(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$e(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$e(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$e(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$e(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function customDataReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_CUSTOM_DATA) {
    return _objectSpread$e(_objectSpread$e({}, state), {}, _defineProperty({}, action.component, action.data));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$9));
    return obj;
  }
  return state;
}

function _toPropertyKey$8(t) { var i = _toPrimitive$8(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$8(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$d(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$d(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$d(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$d(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function defaultQueryReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_DEFAULT_QUERY) {
    return _objectSpread$d(_objectSpread$d({}, state), {}, _defineProperty({}, action.component, action.query));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$8));
    return obj;
  }
  return state;
}

function _toPropertyKey$7(t) { var i = _toPrimitive$7(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$7(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$c(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$c(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$c(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$c(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function customQueryReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_CUSTOM_QUERY) {
    return _objectSpread$c(_objectSpread$c({}, state), {}, _defineProperty({}, action.component, action.query));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$7));
    return obj;
  }
  return state;
}

function _toPropertyKey$6(t) { var i = _toPrimitive$6(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$6(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$b(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$b(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$b(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$b(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function queryOptionsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  switch (action.type) {
    case SET_PROPS:
      return _objectSpread$b(_objectSpread$b({}, state), {}, _defineProperty({}, action.component, action.options));
    case UPDATE_PROPS:
      return _objectSpread$b(_objectSpread$b({}, state), {}, _defineProperty({}, action.component, _objectSpread$b(_objectSpread$b({}, state[action.component]), action.options)));
    case REMOVE_PROPS:
    case REMOVE_COMPONENT:
      {
        var _action$component = action.component;
          state[_action$component];
          var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$6));
        return obj;
      }
    default:
      return state;
  }
}

var _excluded$1 = ["buckets"];
function _toPropertyKey$5(t) { var i = _toPrimitive$5(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$5(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$a(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$a(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$a(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$a(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function aggsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === UPDATE_AGGS) {
    if (action.append) {
      var field = Object.keys(state[action.component])[0];
      var _action$aggregations$ = action.aggregations[field],
        newBuckets = _action$aggregations$.buckets,
        aggsData = _objectWithoutProperties(_action$aggregations$, _excluded$1);
      // console.log('received aggs', action.aggregations);
      return _objectSpread$a(_objectSpread$a({}, state), {}, _defineProperty({}, action.component, _defineProperty({}, field, _objectSpread$a({
        buckets: [].concat(_toConsumableArray(state[action.component][field].buckets), _toConsumableArray(newBuckets))
      }, aggsData))));
    }
    return _objectSpread$a(_objectSpread$a({}, state), {}, _defineProperty({}, action.component, action.aggregations));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component2 = action.component;
      state[_action$component2];
      var obj = _objectWithoutProperties(state, [_action$component2].map(_toPropertyKey$5));
    return obj;
  }
  return state;
}

var _excluded = ["_source"];
function ownKeys$9(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$9(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$9(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$9(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function compositeAggsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === UPDATE_COMPOSITE_AGGS) {
    var aggsResponse = Object.values(action.aggregations) && Object.values(action.aggregations)[0];
    var fieldName = Object.keys(action.aggregations)[0];
    if (!aggsResponse) return state;
    var buckets = [];
    if (aggsResponse.buckets && Array.isArray(aggsResponse.buckets)) {
      buckets = aggsResponse.buckets;
    }
    var parsedAggs = buckets.map(function (bucket) {
      // eslint-disable-next-line camelcase
      var doc_count = bucket.doc_count,
        key = bucket.key,
        hitsData = bucket[fieldName];
      var flatData = {};
      var _source = {};
      if (hitsData && hitsData.hits) {
        var _hitsData$hits$hits$ = hitsData.hits.hits[0];
        _source = _hitsData$hits$hits$._source;
        flatData = _objectWithoutProperties(_hitsData$hits$hits$, _excluded);
      }
      return _objectSpread$9(_objectSpread$9({
        _doc_count: doc_count,
        _key: typeof key === 'string' ? key : key[fieldName],
        top_hits: hitsData
      }, flatData), _source);
    });
    return _objectSpread$9(_objectSpread$9({}, state), {}, _defineProperty({}, action.component, action.append ? [].concat(_toConsumableArray(state[action.component]), _toConsumableArray(parsedAggs)) : parsedAggs));
  }
  return state;
}

function ownKeys$8(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$8(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$8(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$8(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function appliedSettingsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_APPLIED_SETTINGS) {
    return _objectSpread$8(_objectSpread$8({}, state), {}, _defineProperty({}, action.component, action.data));
  }
  return state;
}

function _toPropertyKey$4(t) { var i = _toPrimitive$4(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$4(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$7(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$7(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$7(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$7(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function customHighlightReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_CUSTOM_HIGHLIGHT_OPTIONS) {
    return _objectSpread$7(_objectSpread$7({}, state), {}, _defineProperty({}, action.component, action.data));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$4));
    return obj;
  }
  return state;
}

function _toPropertyKey$3(t) { var i = _toPrimitive$3(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$3(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$6(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$6(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$6(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$6(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function rawDataReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_RAW_DATA) {
    return _objectSpread$6(_objectSpread$6({}, state), {}, _defineProperty({}, action.component, action.response));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$3));
    return obj;
  }
  return state;
}

function ownKeys$5(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$5(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$5(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$5(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function querySuggestionsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_POPULAR_SUGGESTIONS) {
    return _objectSpread$5(_objectSpread$5({}, state), {}, _defineProperty({}, action.component, action.suggestions));
  }
  return state;
}

function ownKeys$4(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$4(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$4(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$4(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function defaultPopularSuggestions() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_DEFAULT_POPULAR_SUGGESTIONS) {
    return _objectSpread$4(_objectSpread$4({}, state), {}, _defineProperty({}, action.component, action.suggestions));
  }
  return state;
}

function _toPropertyKey$2(t) { var i = _toPrimitive$2(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$2(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$3(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$3(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$3(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$3(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function queryToHitsReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_QUERY_TO_HITS) {
    return _objectSpread$3(_objectSpread$3({}, state), {}, _defineProperty({}, action.component, action.query));
  } else if (action.type === REMOVE_COMPONENT) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$2));
    return obj;
  }
  return state;
}

function recentSearchesReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === RECENT_SEARCHES_SUCCESS) {
    return {
      error: null,
      data: action.data
    };
  } else if (action.type === RECENT_SEARCHES_ERROR) {
    return {
      error: action.error
    };
  }
  return state;
}

function ownKeys$2(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$2(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$2(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$2(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var INITIAL_STATE = {
  loading: false,
  loaded: false,
  error: null
};
function googleMapScriptReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : INITIAL_STATE;
  var action = arguments.length > 1 ? arguments[1] : undefined;
  var type = action.type,
    loading = action.loading,
    loaded = action.loaded,
    error = action.error;
  if (type === SET_GOOGLE_MAP_SCRIPT_LOADING) {
    return _objectSpread$2(_objectSpread$2({}, INITIAL_STATE), {}, {
      loading: loading
    });
  } else if (type === SET_GOOGLE_MAP_SCRIPT_LOADED) {
    return _objectSpread$2(_objectSpread$2({}, INITIAL_STATE), {}, {
      loaded: loaded
    });
  } else if (type === SET_GOOGLE_MAP_SCRIPT_ERROR) {
    return _objectSpread$2(_objectSpread$2({}, INITIAL_STATE), {}, {
      error: error
    });
  }
  return state;
}

function analyticsRefReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === ADD_ANALYTICS_REF) {
    return action.analyticsRef;
  }
  return state;
}

function _toPropertyKey$1(t) { var i = _toPrimitive$1(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive$1(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys$1(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread$1(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys$1(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys$1(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function timestampReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_REGISTERED_COMPONENT_TIMESTAMP) {
    return _objectSpread$1(_objectSpread$1({}, state), {}, _defineProperty({}, action.component, action.timestamp));
  } else if (action.type === REMOVE_REGISTERED_COMPONENT_TIMESTAMP) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey$1));
    return obj;
  }
  return state;
}

var _componentTypeToDefau;
(_componentTypeToDefau = {}, _defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_componentTypeToDefau, componentTypes.singleList, ''), componentTypes.multiList, []), componentTypes.singleDataList, ''), componentTypes.singleDropdownList, ''), componentTypes.multiDataList, []), componentTypes.multiDropdownList, []), componentTypes.tagCloud, ''), componentTypes.toggleButton, ''), componentTypes.singleDropdownRange, ''), componentTypes.multiDropdownRange, []), _defineProperty(_defineProperty(_componentTypeToDefau, componentTypes.singleRange, ''), componentTypes.multiRange, []));

// utils/localStorage.js

var setObjectInLocalStorage = function setObjectInLocalStorage(key, value) {
  if (typeof localStorage !== 'undefined') {
    if (!key || !value) {
      throw new Error('Key and value are required for setObject');
    }
    try {
      var serializedValue = JSON.stringify(value);
      localStorage.setItem(key, serializedValue);
    } catch (error) {
      console.error('Error saving object to localStorage:', error);
    }
  } else {
    console.warn('localstorage not available');
  }
};
var getObjectFromLocalStorage = function getObjectFromLocalStorage(key) {
  if (!key) {
    throw new Error('Key is required for getObject');
  }
  try {
    var serializedValue = localStorage.getItem(key);
    if (serializedValue === null) {
      return null;
    }
    return JSON.parse(serializedValue);
  } catch (error) {
    console.error('Error retrieving object from localStorage:', error);
    return null;
  }
};

function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function aiReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments.length > 1 ? arguments[1] : undefined;
  if (action.type === SET_AI_RESPONSE) {
    setObjectInLocalStorage('AISessions', _objectSpread(_objectSpread({}, getObjectFromLocalStorage(AI_LOCAL_CACHE_KEY) || {}), {}, _defineProperty({}, action.component, _objectSpread(_objectSpread({}, state[action.component] || {}), action.payload))));
    return _objectSpread(_objectSpread({}, state), {}, _defineProperty({}, action.component, _objectSpread(_objectSpread({}, state[action.component] ? state[action.component] : {}), {}, {
      response: _objectSpread(_objectSpread({}, state[action.component] ? state[action.component].response : {}), action.payload),
      isLoading: false,
      error: null
    })));
  } else if (action.type === REMOVE_AI_RESPONSE) {
    var _action$component = action.component;
      state[_action$component];
      var obj = _objectWithoutProperties(state, [_action$component].map(_toPropertyKey));
    return obj;
  } else if (action.type === SET_AI_RESPONSE_ERROR) {
    return _objectSpread(_objectSpread({}, state), {}, _defineProperty({}, action.component, _objectSpread(_objectSpread({}, state[action.component] ? state[action.component] : {}), {}, {
      error: action.error,
      isLoading: false,
      response: null
    }, action.meta || {})));
  } else if (action.type === SET_AI_RESPONSE_LOADING) {
    return _objectSpread(_objectSpread({}, state), {}, _defineProperty({}, action.component, _objectSpread(_objectSpread({}, state[action.component] ? state[action.component] : {}), {}, {
      isLoading: action.isLoading
    })));
  }
  return state;
}

var index = combineReducers({
  components: componentsReducer,
  customQueries: customQueryReducer,
  defaultQueries: defaultQueryReducer,
  customHighlightOptions: customHighlightReducer,
  settings: appliedSettingsReducer,
  watchMan: watchManReducer,
  // contains the list of subscribers
  queryList: queryReducer,
  queryOptions: queryOptionsReducer$1,
  dependencyTree: dependencyTreeReducer,
  appbaseRef: appbaseRefReducer,
  analyticsRef: analyticsRefReducer,
  config: configReducer,
  hits: hitsReducer,
  promotedResults: promotedResultsReducer,
  customData: customDataReducer,
  aggregations: aggsReducer,
  compositeAggregations: compositeAggsReducer,
  queryLog: logsReducer,
  combinedLog: combinedLogsReducer,
  selectedValues: valueReducer$1,
  internalValues: valueReducer,
  isLoading: loadingReducer,
  error: errorReducer,
  timestamp: timestampReducer$1,
  headers: headersReducer,
  mapData: mapDataReducer,
  // holds the map id and boolean to execute geo-bound-query
  queryListener: queryListenerReducer,
  analytics: analyticsReducer,
  props: queryOptionsReducer,
  rawData: rawDataReducer,
  querySuggestions: querySuggestionsReducer,
  defaultPopularSuggestions: defaultPopularSuggestions,
  queryToHits: queryToHitsReducer,
  // holds the query value for last fetched `hits`
  recentSearches: recentSearchesReducer,
  urlValues: function urlValues() {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    return state;
  },
  googleMapScriptStatus: googleMapScriptReducer,
  lastUsedAppbaseQuery: appbaseQueryReducer,
  registeredComponentsTimestamps: timestampReducer,
  AIResponses: aiReducer
});

export { index as default };
