function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(r, l) {
  var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (null != t) {
    var e,
      n,
      i,
      u,
      a = [],
      f = !0,
      o = !1;
    try {
      if (i = (t = t.call(r)).next, 0 === l) {
        if (Object(t) !== t) return;
        f = !1;
      } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0);
    } catch (r) {
      o = !0, n = r;
    } finally {
      try {
        if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return;
      } finally {
        if (o) throw n;
      }
    }
    return a;
  }
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;
  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
  return arr2;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _typeof(o) {
  "@babel/helpers - typeof";

  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) {
    return typeof o;
  } : function (o) {
    return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o;
  }, _typeof(o);
}

var componentTypes = {
  reactiveList: 'REACTIVELIST',
  // search components
  dataSearch: 'DATASEARCH',
  categorySearch: 'CATEGORYSEARCH',
  searchBox: 'SEARCHBOX',
  // list components
  singleList: 'SINGLELIST',
  multiList: 'MULTILIST',
  singleDataList: 'SINGLEDATALIST',
  tabDataList: 'TABDATALIST',
  singleDropdownList: 'SINGLEDROPDOWNLIST',
  multiDataList: 'MULTIDATALIST',
  multiDropdownList: 'MULTIDROPDOWNLIST',
  singleDropdownRange: 'SINGLEDROPDOWNRANGE',
  treeList: 'TREELIST',
  // basic components
  numberBox: 'NUMBERBOX',
  tagCloud: 'TAGCLOUD',
  toggleButton: 'TOGGLEBUTTON',
  reactiveComponent: 'REACTIVECOMPONENT',
  // range components
  datePicker: 'DATEPICKER',
  dateRange: 'DATERANGE',
  dynamicRangeSlider: 'DYNAMICRANGESLIDER',
  multiDropdownRange: 'MULTIDROPDOWNRANGE',
  singleRange: 'SINGLERANGE',
  multiRange: 'MULTIRANGE',
  rangeSlider: 'RANGESLIDER',
  ratingsFilter: 'RATINGSFILTER',
  rangeInput: 'RANGEINPUT',
  // map components
  geoDistanceDropdown: 'GEO_DISTANCE_DROPDOWN',
  geoDistanceSlider: 'GEO_DISTANCE_SLIDER',
  reactiveMap: 'REACTIVE_MAP',
  // chart components
  reactiveChart: 'REACTIVE_CHART',
  // ai component
  AIAnswer: 'AI_ANSWER'
};

var filterComponents = [componentTypes.numberBox, componentTypes.tagCloud, componentTypes.toggleButton, componentTypes.datePicker, componentTypes.dateRange, componentTypes.multiDataList, componentTypes.multiDropdownList, componentTypes.multiList, componentTypes.singleDataList, componentTypes.singleDropdownList, componentTypes.singleList, componentTypes.dynamicRangeSlider, componentTypes.multiDropdownRange, componentTypes.multiRange, componentTypes.rangeSlider, componentTypes.ratingsFilter, componentTypes.singleDropdownRange, componentTypes.singleRange, componentTypes.treeList];

// components storing range as array
var rangeComponents = [componentTypes.dateRange, componentTypes.dynamicRangeSlider, componentTypes.rangeSlider, componentTypes.rangeInput, componentTypes.ratingsFilter];

// components storing range as object
var rangeObjectComponents = [componentTypes.singleRange, componentTypes.singleDropdownRange, componentTypes.multiRange, componentTypes.multiDropdownRange];
function parseRangeObject(filterKey, rangeObject) {
  return "".concat(filterKey, "=").concat(rangeObject.start, "~").concat(rangeObject.end);
}
function parseFilterValue(componentId, componentValues) {
  var label = componentValues.label,
    value = componentValues.value,
    componentType = componentValues.componentType;
  var filterKey = label || componentId;
  if (rangeComponents.includes(componentType)) {
    // range components store values as an array to depict start and end range
    return "".concat(filterKey, "=").concat(value[0], "~").concat(value[1]);
  } else if (rangeObjectComponents.includes(componentType)) {
    // for range components with values in the form { start, end }
    if (Array.isArray(value)) {
      return value.map(function (item) {
        return parseRangeObject(filterKey, item);
      }).join();
    }
    return parseRangeObject(filterKey, value);
  } else if (Array.isArray(value)) {
    // for components having values in the form { label, value }
    var isObject = _typeof(value[0]) === 'object' && value[0] !== null;
    return isObject ? value.map(function (item) {
      return "".concat(filterKey, "=").concat(item.value);
    }).join() : value.map(function (item) {
      return "".concat(filterKey, "=").concat(item);
    }).join();
  }
  return "".concat(filterKey, "=").concat(value);
}

// transforms the selectedValues from store into the X-Search-Filters string for analytics
function getFilterString(selectedValues) {
  if (selectedValues && Object.keys(selectedValues).length) {
    return Object
    // take all selectedValues
    .entries(selectedValues)
    // filter out filter components having some value
    .filter(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 2),
        componentValues = _ref2[1];
      return filterComponents.includes(componentValues.componentType)
      // in case of an array filter out empty array values as well
      && (componentValues.value && componentValues.value.length
      // also consider range values in the shape { start, end }
      || componentValues.value && componentValues.value.start || componentValues.value && componentValues.value.end);
    })
    // parse each filter value
    .map(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 2),
        componentId = _ref4[0],
        componentValues = _ref4[1];
      return parseFilterValue(componentId, componentValues);
    })
    // return as a string separated with comma
    .join();
  }
  return null;
}

/**
 * Function to parse the custom analytics events
 */
function parseCustomEvents(customEvents) {
  var finalStr = '';
  Object.keys(customEvents).forEach(function (key, index) {
    finalStr += "".concat(key, "=").concat(customEvents[key]);
    if (index < Object.keys(customEvents).length - 1) {
      finalStr += ',';
    }
  });
  return finalStr;
}

// defaultAnalytics Config
var defaultAnalyticsConfig = {
  emptyQuery: true,
  suggestionAnalytics: true,
  userId: null,
  customEvents: null,
  enableQueryRules: true
};

export { getFilterString as default, defaultAnalyticsConfig, filterComponents, parseCustomEvents, parseFilterValue, parseRangeObject, rangeComponents, rangeObjectComponents };
